==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtcalenderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "J_[̍쐬"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-R*/
#define RNGT "N͈"
#define RNGC ") 200201_200212Aw肪Ȃ΍"

/*-p*/
#define PADT "O㌎̃pfBO"
#define PADC "J_[̑TƍŏIT̑O㌎̓o͂"

/*-m*/
#define MONT "jT̍ŏ̗jɂ"
#define MONC "-pw肵Ȃ΂ȂȂ"

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "w肳ꂽ͈͂̃J_[o͂Bo͍ڂyear,month,dateB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcalender -o rsl.xt\n\
  )̃J_[o͂B\n\
xtcalender -R 200303 -o rsl.xt\n\
  )2003N3̃J_[o͂B\n\
xtcalender -R 200303_200306 -o rsl.xt\n\
  )2003N36̃J_[o͂B\n\
xtcalender -R 200303 -p -o rsl.xt\n\
  )2003N3̃J_[AO㌎̍ŏI(ŏ)Tŏo͂B\n\
xtcalender -R 200303 -p -m -o rsl.xt\n\
  )2003N3̃J_[Ajŏ̗jƂđO㌎̍ŏI(ŏ)Tŏo͂B\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtcal,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-sjis/xtcalenderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "J_[̍쐬"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-R*/
#define RNGT "N͈"
#define RNGC ") 200201_200212Aw肪Ȃ΍"

/*-p*/
#define PADT "O㌎̃pfBO"
#define PADC "J_[̑TƍŏIT̑O㌎̓o͂"

/*-m*/
#define MONT "jT̍ŏ̗jɂ"
#define MONC "-pw肵Ȃ΂ȂȂ"

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "w肳ꂽ͈͂̃J_[o͂Bo͍ڂyear,month,dateB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcalender -o rsl.xt\n\
  )̃J_[o͂B\n\
xtcalender -R 200303 -o rsl.xt\n\
  )2003N3̃J_[o͂B\n\
xtcalender -R 200303_200306 -o rsl.xt\n\
  )2003N36̃J_[o͂B\n\
xtcalender -R 200303 -p -o rsl.xt\n\
  )2003N3̃J_[AO㌎̍ŏI(ŏ)Tŏo͂B\n\
xtcalender -R 200303 -p -m -o rsl.xt\n\
  )2003N3̃J_[Ajŏ̗jƂđO㌎̍ŏI(ŏ)Tŏo͂B\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtcal,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
